@@ -32,10 +32,7 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner",
-    "2.2.374",
-    __name__[0:-6],
-    "cdk-gitlab-runner@2.2.374.jsii.tgz",
+    "cdk-gitlab-runner", "2.3.85", __name__[0:-6], "cdk-gitlab-runner@2.3.85.jsii.tgz"
 )
 
 __all__ = [
